<?php
/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @since      1.0.0
 * @package    Proofreading
 * @subpackage Proofreading/admin/partials
 * @author     Scribit <wordpress@scribit.it>
 */

function proofreading_admin_page_handler() {
	//$current_page = str_replace('settings_page_proofreading/', '', get_current_screen()->id);
	$current_page = isset($_GET['subpage']) ? $_GET['subpage'] : 'settings';
?>
	<div class="wrap proofreading-backend proofreading-<?= $current_page ?>">
		<h1><?= __('Proofreading', 'proofreading') . ' - ' . __('Settings','proofreading') ?></h1>
		
		<h2 class="nav-tab-wrapper"> 
			<a href="options-general.php?page=<?= PROOFREADING_PLUGIN_SLUG ?>" class="nav-tab <?= ($current_page == 'settings') ? 'nav-tab-active' : '' ?>">
				<?= __('Languages','proofreading') ?>
			</a> 
			<a href="options-general.php?page=<?= PROOFREADING_PLUGIN_SLUG ?>&subpage=about" class="nav-tab <?= ($current_page == 'about') ? 'nav-tab-active' : '' ?>">
				<?= __('About','proofreading') ?>
			</a>
		</h2>
		
		<div class="proofreading-tab-content"><?php
		
		switch($current_page){
			case 'settings':
				proofreading_admin_page_settings_handler();
				break;
			
			case 'about':
					proofreading_admin_page_about_handler();
					break;
		}
		?></div>
	</div><?php
}
 
function proofreading_admin_page_settings_handler() {
	
	if (isset($_POST['submit'])) {
		$res = true;
		$nonce = $_POST['nonce'];
		
		if ( wp_verify_nonce( $_POST['nonce'], 'proofreading-admin-menu-save' ) ){
			update_option("proofreading-language-default", $_POST['proofreading-language-default'] );
			
			if (isset($_POST['rules'])){
				global $wpdb;
				$wpdb->delete( "{$wpdb->prefix}proofreading_rules_settings", array( 'lang_code' => $_POST['proofreading-language-rules-settings'] ), array( '%s' ) );
				$wpdb->insert( 
					"{$wpdb->prefix}proofreading_rules_settings", 
					array( 
						'lang_code' => $_POST['proofreading-language-rules-settings'], 
						'included_rules' => implode(',', $_POST['rules']) 
					), 
					array( '%s', '%s' ) 
				);
			}
		}
		else $res = false;
		?>
		<div id="setting-error-settings_updated" class="<?= $res ? '' : 'error' ?> updated settings-error notice is-dismissible"> 
			<p><strong><?= $res ? __('Settings saved.','proofreading') : __('Saving Error.','proofreading') ?></strong></p>
			<button type="button" class="notice-dismiss">
				<span class="screen-reader-text"><?= __('Dismiss this notice.','proofreading') ?></span>
			</button>
		</div>
<?php }
	else
	{
		$nonce = wp_create_nonce( 'proofreading-admin-menu-save' );
	} 
?>
	
	<form method="post" novalidate="novalidate">
		<input type="hidden" name="nonce" value="<?= $nonce ?>" />
		<table class="form-table">
			<tbody>
				<tr>
					<th scope="row"><label for="proofreading-language-default"><?= __('Default correction Language','proofreading') .':' ?></label></th>
					<td>
						<?php global $wpdb;
							$languages = $wpdb->get_results("SELECT name, code
								FROM {$wpdb->prefix}proofreading_languages
								WHERE active = 1", ARRAY_A);
						?>
						<select id="proofreading-language-default" name="proofreading-language-default">
							<?php $current_value = get_option( "proofreading-language-default", 2 );
								foreach ($languages as $language): ?>
								<option <?= $current_value == $language['code'] ? 'selected' : '' ?> value="<?= $language['code'] ?>"><?= $language['name'] ?></option>
							<?php endforeach; ?>
						</select>
					</td>
				</tr>
				<tr>
					<th scope="row">
						<label><?= __('Rules category', 'proofreading') ?></label>
						<p class="description" id="tagline-description"><?= __('Enable or disable types of rule to be checked in the corrections.', 'proofreading') ?></p>
						<p><?= __('Select the language to manage the rules:', 'proofreading') ?></p>
						<select id="proofreading-language-rules-settings" name="proofreading-language-rules-settings">
							<?php $current_value = isset($_POST['proofreading-language-rules-settings']) ? $_POST['proofreading-language-rules-settings'] : get_option( "proofreading-language-default", 2 );
								foreach ($languages as $language): ?>
								<option <?= $current_value == $language['code'] ? 'selected' : '' ?> value="<?= $language['code'] ?>"><?= $language['name'] ?></option>
							<?php endforeach; ?>
						</select>
					</th>
					<td>
						<table class="proofreading_rules">
							<thead>
								<tr class="select_all_rules_row" style="display:none">
									<td><label for="select_all_rules"><input type="checkbox" id="select_all_rules"> <strong><?= __('Select all rules', 'proofreading') ?><strong></label></td>
								</tr>
							</thead>
							<tbody class="rules_container"></tbody>
						</table>
						
					</td>
				</tr>
			</tbody>
		</table>
		
		<p class="submit"><input type="submit" name="submit" id="submit" class="button button-primary" value="<?= __('Save settings', 'proofreading') ?>"></p>
	</form>
	
<?php }

function proofreading_admin_page_about_handler(){ ?>
	
	<h3><?= __('Support', 'proofreading') ?></h3>
	<ul id="proofreading_support" style="font-size: 110%">
		<li>
			<?= __('If you like our plugin please feel free to give us 5 stars :)', 'proofreading') ?>&nbsp;&nbsp;&nbsp;
			<a target="_blank" class="button" rel="nofollow" href="https://wordpress.org/support/plugin/proofreading/reviews/">
				<span style="color:#080" class="fa fa-star">&nbsp;&nbsp;<?= __('WRITE A PLUGIN REVIEW', 'proofreading') ?></a>
		</li>
		
		<li>
			<?= __('If you want to help us to improve our service please Donate a coffe', 'proofreading') ?>&nbsp;&nbsp;&nbsp;
			<a target="_blank" class="button" rel="nofollow" href="https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=riccardosormani@gmail.com&item_name=Proofreading Wordpress plugin donation&no_note=0">
				<span  style="color:#950" class="fa fa-coffee">&nbsp;&nbsp;<?= __('DONATE WITH PAYPAL', 'proofreading') ?></a>
		</li>
		
		<li>
			<?= __('If you want some information about our Company', 'proofreading') ?>&nbsp;&nbsp;&nbsp;
			<a target="_blank" class="button" href="mailto:wordpress@scribit.it"><span class="fa fa-envelope">&nbsp;&nbsp;<?= __('CONTACT US', 'proofreading') ?></a>
		</li>
	</ul>
	
	<p> </p>
	<p style="margin-top:3em" id="footer-thankyou"><?php
		$url = 'https://languagetool.org';
		echo sprintf( wp_kses( __( 'Thanks to <a target="_blank" href="%s">Languagetool.org</a> services.', 'proofreading' ), array('a' => array('href' => array(), 'target' => array())) ), esc_url($url) );
	?></p>
	
<?php }